summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmtreeview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmtreeview.h')
-rw-r--r--kpovmodeler/pmtreeview.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kpovmodeler/pmtreeview.h b/kpovmodeler/pmtreeview.h
index 445b53fd..7b9ea1d0 100644
--- a/kpovmodeler/pmtreeview.h
+++ b/kpovmodeler/pmtreeview.h
@@ -41,7 +41,7 @@ public:
/**
* Default constructor
*/
- PMTreeViewWidget( PMPart* pare, TQWidget* tqparent, const char* name = 0 );
+ PMTreeViewWidget( PMPart* pare, TQWidget* parent, const char* name = 0 );
/** */
virtual TQString viewType( ) const { return TQString( "treeview" ); }
@@ -59,10 +59,10 @@ class PMTreeView : public TQListView
friend class PMTreeViewItem;
public:
/**
* Creates a PMTreeView with tqparent and name that displays the
* document doc
*/
- PMTreeView( PMPart* part, TQWidget* tqparent = 0, const char* name = 0 );
+ PMTreeView( PMPart* part, TQWidget* parent = 0, const char* name = 0 );
/**
* Deletes the PMTreeView
*/
@@ -174,9 +174,9 @@ public:
virtual TQString viewType( ) const { return TQString( "treeview" ); }
virtual TQString description( ) const;
virtual TQString iconName( ) const { return TQString( "pmtreeview" ); }
- virtual PMViewBase* newInstance( TQWidget* tqparent, PMPart* part ) const
+ virtual PMViewBase* newInstance( TQWidget* parent, PMPart* part ) const
{
- return new PMTreeViewWidget( part, tqparent );
+ return new PMTreeViewWidget( part, parent );
}
};
@@ -59,10 +59,10 @@ class PMTreeView : public TQListView
public:
/**
- * Creates a PMTreeView with tqparent and name that displays the
+ * Creates a PMTreeView with parent and name that displays the
* document doc
*/